@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2023 the original author or authors.
+ * Copyright 2015-2024 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -50,7 +50,7 @@ import org.junit.jupiter.api.extension.ExtensionContext;
 @TestInstance(Lifecycle.PER_CLASS)
 abstract class AbstractExecutionConditionTests {
 
-	private final ExtensionContext context = mock(ExtensionContext.class);
+	private final ExtensionContext context = mock();
 
 	private ConditionEvaluationResult result;
 
