@@ -1,7 +1,7 @@
 plugins {
-	`java-library-conventions`
-	`junit4-compatibility`
-	`testing-conventions`
+	id("junitbuild.java-library-conventions")
+	id("junitbuild.junit4-compatibility")
+	id("junitbuild.testing-conventions")
 }
 
 description = "JUnit Jupiter Migration Support"
@@ -24,10 +24,11 @@ dependencies {
 
 tasks.jar {
 	bundle {
+		val importAPIGuardian: String by extra
 		bnd("""
 			# Import JUnit4 packages with a version
 			Import-Package: \
-				${extra["importAPIGuardian"]},\
+				$importAPIGuardian,\
 				org.junit;version="[${libs.versions.junit4Min.get()},5)",\
 				org.junit.platform.commons.logging;status=INTERNAL,\
 				org.junit.rules;version="[${libs.versions.junit4Min.get()},5)",\
