@@ -1,7 +1,7 @@
 plugins {
-	`kotlin-library-conventions`
-	`shadow-conventions`
-	`testing-conventions`
+	id("junitbuild.kotlin-library-conventions")
+	id("junitbuild.shadow-conventions")
+	id("junitbuild.testing-conventions")
 }
 
 description = "JUnit Jupiter Params"
@@ -18,6 +18,7 @@ dependencies {
 	testImplementation(projects.junitJupiterEngine)
 	testImplementation(projects.junitPlatformLauncher)
 	testImplementation(projects.junitPlatformSuiteEngine)
+	testImplementation(testFixtures(projects.junitPlatformCommons))
 	testImplementation(testFixtures(projects.junitJupiterEngine))
 
 	compileOnly(kotlin("stdlib"))
@@ -30,10 +31,11 @@ dependencies {
 tasks {
 	jar {
 		bundle {
+			val version = project.version
 			bnd("""
 				Require-Capability:\
 					org.junit.platform.engine;\
-						filter:='(&(org.junit.platform.engine=junit-jupiter)(version>=${'$'}{version_cleanup;${rootProject.property("version")!!}})(!(version>=${'$'}{versionmask;+;${'$'}{version_cleanup;${rootProject.property("version")!!}}})))';\
+						filter:='(&(org.junit.platform.engine=junit-jupiter)(version>=${'$'}{version_cleanup;$version})(!(version>=${'$'}{versionmask;+;${'$'}{version_cleanup;$version}})))';\
 						effective:=active
 			""")
 		}
@@ -48,4 +50,10 @@ tasks {
 			into("META-INF")
 		}
 	}
+	compileModule {
+		options.compilerArgs.addAll(listOf(
+			"--add-modules", "univocity.parsers",
+			"--add-reads", "${javaModuleName}=univocity.parsers"
+		))
+	}
 }
