@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2023 the original author or authors.
+ * Copyright 2015-2024 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -43,10 +43,17 @@ public enum Details {
 	/**
 	 * Combines {@link #TREE} and {@link #FLAT} modes.
 	 */
-	VERBOSE;
+	VERBOSE,
 
 	/**
-	 * Return lower case {@link #name} for easier usage in help text for
+	 * Test plan execution events are rendered as they occur in a concise format.
+	 *
+	 * @since 1.10
+	 */
+	TESTFEED;
+
+	/**
+	 * Return lower case {@link #name()} for easier usage in help text for
 	 * available options.
 	 */
 	@Override
