@@ -1,27 +1,26 @@
 /*
- * Copyright 2015-2018 the original author or authors.
+ * Copyright 2015-2024 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
  * accompanies this distribution and is available at
  *
- * http://www.eclipse.org/legal/epl-v20.html
+ * https://www.eclipse.org/legal/epl-v20.html
  */
 
 package org.junit.platform.engine.support.hierarchical;
 
-import static org.apiguardian.api.API.Status.EXPERIMENTAL;
+import static org.apiguardian.api.API.Status.STABLE;
 
 import org.apiguardian.api.API;
 
 /**
  * A lock for a one or more resources.
  *
- * @see HierarchicalTestExecutorService.TestTask#getResourceLock()
- *
  * @since 1.3
+ * @see HierarchicalTestExecutorService.TestTask#getResourceLock()
  */
-@API(status = EXPERIMENTAL, since = "1.3")
+@API(status = STABLE, since = "1.10")
 public interface ResourceLock extends AutoCloseable {
 
 	/**
