@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2023 the original author or authors.
+ * Copyright 2015-2024 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -10,6 +10,8 @@
 
 package org.junit.platform.suite.api;
 
+import static org.apiguardian.api.API.Status.STABLE;
+
 import java.lang.annotation.Documented;
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Inherited;
@@ -18,7 +20,6 @@ import java.lang.annotation.RetentionPolicy;
 import java.lang.annotation.Target;
 
 import org.apiguardian.api.API;
-import org.apiguardian.api.API.Status;
 
 /**
  * Disable parent configuration parameters.
@@ -39,6 +40,6 @@ import org.apiguardian.api.API.Status;
 @Target(ElementType.TYPE)
 @Inherited
 @Documented
-@API(status = Status.EXPERIMENTAL, since = "1.8")
+@API(status = STABLE, since = "1.10")
 public @interface DisableParentConfigurationParameters {
 }
