@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2023 the original author or authors.
+ * Copyright 2015-2024 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -52,6 +52,7 @@ import java.util.logging.LogRecord;
 import java.util.stream.IntStream;
 import java.util.stream.Stream;
 
+import org.junit.jupiter.api.Disabled;
 import org.junit.jupiter.api.Nested;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.fixtures.TrackLogRecords;
@@ -1351,10 +1352,11 @@ class ReflectionUtilsTests {
 	}
 
 	/**
-	 * @see https://github.com/junit-team/junit5/issues/3498
+	 * @see https://github.com/junit-team/junit5/issues/3553
 	 */
+	@Disabled("Until #3553 is resolved")
 	@Test
-	void findMethodsAppliesPredicateBeforeSearchingTypeHierarchy() throws Exception {
+	void findMethodsDoesNotAllowInstanceMethodToHideStaticMethod() throws Exception {
 		final String BEFORE = "before";
 		Class<?> superclass = SuperclassWithStaticPackagePrivateBeforeMethod.class;
 		Method staticMethod = superclass.getDeclaredMethod(BEFORE);
@@ -1383,10 +1385,11 @@ class ReflectionUtilsTests {
 	}
 
 	/**
-	 * @see https://github.com/junit-team/junit5/issues/3532
+	 * @see https://github.com/junit-team/junit5/issues/3553
 	 */
+	@Disabled("Until #3553 is resolved")
 	@Test
-	void findFieldsAppliesPredicateBeforeSearchingTypeHierarchy() throws Exception {
+	void findFieldsDoesNotAllowInstanceFieldToHideStaticField() throws Exception {
 		final String TEMP_DIR = "tempDir";
 		Class<?> superclass = SuperclassWithStaticPackagePrivateTempDirField.class;
 		Field staticField = superclass.getDeclaredField(TEMP_DIR);
