@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2023 the original author or authors.
+ * Copyright 2015-2024 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -86,7 +86,7 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 		class Suite {
 		}
 
-		LauncherDiscoveryRequest request = builder.suite(Suite.class).build();
+		LauncherDiscoveryRequest request = builder.applyConfigurationParametersFromSuite(Suite.class).build();
 		ConfigurationParameters configuration = request.getConfigurationParameters();
 		Optional<String> parameter = configuration.get("com.example");
 		assertEquals(Optional.of("*"), parameter);
@@ -100,7 +100,7 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 		class Suite {
 		}
 
-		LauncherDiscoveryRequest request = builder.suite(Suite.class).build();
+		LauncherDiscoveryRequest request = builder.applySelectorsAndFiltersFromSuite(Suite.class).build();
 		List<ClassNameFilter> filters = request.getFiltersByType(ClassNameFilter.class);
 		assertTrue(exactlyOne(filters).apply(TestCase.class.getName()).excluded());
 	}
@@ -111,7 +111,7 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 		class Suite {
 		}
 
-		LauncherDiscoveryRequest request = builder.suite(Suite.class).build();
+		LauncherDiscoveryRequest request = builder.applySelectorsAndFiltersFromSuite(Suite.class).build();
 		List<EngineFilter> filters = request.getEngineFilters();
 		assertTrue(exactlyOne(filters).apply(new JupiterTestEngine()).excluded());
 	}
@@ -122,7 +122,7 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 		class Suite {
 		}
 
-		LauncherDiscoveryRequest request = builder.suite(Suite.class).build();
+		LauncherDiscoveryRequest request = builder.applySelectorsAndFiltersFromSuite(Suite.class).build();
 		List<PackageNameFilter> filters = request.getFiltersByType(PackageNameFilter.class);
 		assertTrue(exactlyOne(filters).apply("com.example.testcases").excluded());
 	}
@@ -133,7 +133,7 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 		class Suite {
 		}
 
-		LauncherDiscoveryRequest request = builder.suite(Suite.class).build();
+		LauncherDiscoveryRequest request = builder.applySelectorsAndFiltersFromSuite(Suite.class).build();
 		List<PostDiscoveryFilter> filters = request.getPostDiscoveryFilters();
 		TestDescriptor testDescriptor = new StubAbstractTestDescriptor();
 		assertTrue(exactlyOne(filters).apply(testDescriptor).excluded());
@@ -147,7 +147,7 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 		class Suite {
 		}
 
-		LauncherDiscoveryRequest request = builder.suite(Suite.class).build();
+		LauncherDiscoveryRequest request = builder.applySelectorsAndFiltersFromSuite(Suite.class).build();
 		List<ClassNameFilter> filters = request.getFiltersByType(ClassNameFilter.class);
 		assertTrue(exactlyOne(filters).apply(TestCase.class.getName()).included());
 		assertTrue(exactlyOne(filters).apply(Suite.class.getName()).excluded());
@@ -158,7 +158,7 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 		class Suite {
 		}
 
-		LauncherDiscoveryRequest request = builder.suite(Suite.class).build();
+		LauncherDiscoveryRequest request = builder.applySelectorsAndFiltersFromSuite(Suite.class).build();
 		assertTrue(request.getFiltersByType(ClassNameFilter.class).isEmpty());
 	}
 
@@ -172,7 +172,7 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 		// @formatter:off
 		LauncherDiscoveryRequest request = builder
 				.filterStandardClassNamePatterns(true)
-				.suite(Suite.class)
+				.applySelectorsAndFiltersFromSuite(Suite.class)
 				.build();
 		// @formatter:on
 		List<ClassNameFilter> filters = request.getFiltersByType(ClassNameFilter.class);
@@ -186,7 +186,7 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 		class Suite {
 		}
 
-		LauncherDiscoveryRequest request = builder.suite(Suite.class).build();
+		LauncherDiscoveryRequest request = builder.applySelectorsAndFiltersFromSuite(Suite.class).build();
 		List<EngineFilter> filters = request.getEngineFilters();
 		assertTrue(exactlyOne(filters).apply(new JupiterTestEngine()).included());
 	}
@@ -197,7 +197,7 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 		class Suite {
 		}
 
-		LauncherDiscoveryRequest request = builder.suite(Suite.class).build();
+		LauncherDiscoveryRequest request = builder.applySelectorsAndFiltersFromSuite(Suite.class).build();
 		List<PackageNameFilter> filters = request.getFiltersByType(PackageNameFilter.class);
 		assertTrue(exactlyOne(filters).apply("com.example.testcases").included());
 	}
@@ -208,7 +208,7 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 		class Suite {
 		}
 
-		LauncherDiscoveryRequest request = builder.suite(Suite.class).build();
+		LauncherDiscoveryRequest request = builder.applySelectorsAndFiltersFromSuite(Suite.class).build();
 		List<PostDiscoveryFilter> filters = request.getPostDiscoveryFilters();
 		TestDescriptor testDescriptor = new StubAbstractTestDescriptor();
 		assertTrue(exactlyOne(filters).apply(testDescriptor).included());
@@ -222,7 +222,7 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 		class Suite {
 		}
 
-		LauncherDiscoveryRequest request = builder.suite(Suite.class).build();
+		LauncherDiscoveryRequest request = builder.applySelectorsAndFiltersFromSuite(Suite.class).build();
 		List<ClassSelector> selectors = request.getSelectorsByType(ClassSelector.class);
 		assertFalse(selectors.isEmpty());
 		assertEquals(TestCase.class, exactlyOne(selectors).getJavaClass());
@@ -234,7 +234,7 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 		class Suite {
 		}
 
-		LauncherDiscoveryRequest request = builder.suite(Suite.class).build();
+		LauncherDiscoveryRequest request = builder.applySelectorsAndFiltersFromSuite(Suite.class).build();
 		List<ClassSelector> selectors = request.getSelectorsByType(ClassSelector.class);
 		assertEquals(NonLocalTestCase.class, exactlyOne(selectors).getJavaClass());
 	}
@@ -245,7 +245,8 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 		class Suite {
 		}
 
-		var e = assertThrows(PreconditionViolationException.class, () -> builder.suite(Suite.class));
+		var e = assertThrows(PreconditionViolationException.class,
+			() -> builder.applySelectorsAndFiltersFromSuite(Suite.class));
 
 		assertThat(e).hasMessageMatching(
 			"@SelectClasses on class \\[" + Pattern.quote(SuiteLauncherDiscoveryRequestBuilderTests.class.getName())
@@ -269,7 +270,7 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 
 		return Stream.of(SuiteA.class, SuiteB.class, SuiteC.class) //
 				.map(suiteClass -> dynamicTest(suiteClass.getSimpleName(), () -> {
-					LauncherDiscoveryRequest request = request().suite(suiteClass).build();
+					LauncherDiscoveryRequest request = request().applySelectorsAndFiltersFromSuite(suiteClass).build();
 					List<MethodSelector> selectors = request.getSelectorsByType(MethodSelector.class);
 					assertEquals(DiscoverySelectors.selectMethod(NoParameterTestCase.class, "testMethod"),
 						exactlyOne(selectors));
@@ -302,7 +303,7 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 
 		return Stream.of(SuiteA.class, SuiteB.class, SuiteC.class, SuiteD.class, SuiteE.class) //
 				.map(suiteClass -> dynamicTest(suiteClass.getSimpleName(), () -> {
-					LauncherDiscoveryRequest request = request().suite(suiteClass).build();
+					LauncherDiscoveryRequest request = request().applySelectorsAndFiltersFromSuite(suiteClass).build();
 					List<MethodSelector> selectors = request.getSelectorsByType(MethodSelector.class);
 					assertEquals(DiscoverySelectors.selectMethod(OneParameterTestCase.class, "testMethod", "int"),
 						exactlyOne(selectors));
@@ -331,7 +332,7 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 		class Suite {
 		}
 
-		LauncherDiscoveryRequest request = builder.suite(Suite.class).build();
+		LauncherDiscoveryRequest request = builder.applySelectorsAndFiltersFromSuite(Suite.class).build();
 		List<MethodSelector> selectors = request.getSelectorsByType(MethodSelector.class);
 		assertEquals(2, selectors.size());
 		assertEquals(DiscoverySelectors.selectMethod(TestClass.class, "firstTestMethod", "int, java.lang.String"),
@@ -387,7 +388,7 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 					var expectedFailureMessage = entry.getValue();
 					return dynamicTest(suiteClassName.getSimpleName(), () -> {
 						var ex = assertThrows(PreconditionViolationException.class,
-							() -> request().suite(suiteClassName));
+							() -> request().applySelectorsAndFiltersFromSuite(suiteClassName));
 						assertEquals(
 							"@SelectMethod on class [" + suiteClassName.getName() + "]: " + expectedFailureMessage,
 							ex.getMessage());
@@ -401,7 +402,7 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 		class Suite {
 		}
 
-		LauncherDiscoveryRequest request = builder.suite(Suite.class).build();
+		LauncherDiscoveryRequest request = builder.applySelectorsAndFiltersFromSuite(Suite.class).build();
 		List<ClasspathResourceSelector> selectors = request.getSelectorsByType(ClasspathResourceSelector.class);
 		assertEquals("com.example.testcases", exactlyOne(selectors).getClasspathResourceName());
 	}
@@ -413,7 +414,7 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 		class Suite {
 		}
 
-		LauncherDiscoveryRequest request = builder.suite(Suite.class).build();
+		LauncherDiscoveryRequest request = builder.applySelectorsAndFiltersFromSuite(Suite.class).build();
 		List<ClasspathResourceSelector> selectors = request.getSelectorsByType(ClasspathResourceSelector.class);
 		assertEquals(Optional.of(FilePosition.from(42)), selectors.get(0).getPosition());
 		assertEquals(Optional.of(FilePosition.from(14, 15)), selectors.get(1).getPosition());
@@ -427,7 +428,7 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 		class Suite {
 		}
 
-		LauncherDiscoveryRequest request = builder.suite(Suite.class).build();
+		LauncherDiscoveryRequest request = builder.applySelectorsAndFiltersFromSuite(Suite.class).build();
 		List<ClasspathResourceSelector> selectors = request.getSelectorsByType(ClasspathResourceSelector.class);
 		assertEquals(Optional.empty(), selectors.get(0).getPosition());
 		assertEquals(Optional.empty(), selectors.get(1).getPosition());
@@ -440,7 +441,7 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 		class Suite {
 		}
 
-		LauncherDiscoveryRequest request = builder.suite(Suite.class).build();
+		LauncherDiscoveryRequest request = builder.applySelectorsAndFiltersFromSuite(Suite.class).build();
 		List<DirectorySelector> selectors = request.getSelectorsByType(DirectorySelector.class);
 		assertEquals(Paths.get("path/to/root"), exactlyOne(selectors).getPath());
 	}
@@ -451,7 +452,7 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 		class Suite {
 		}
 
-		LauncherDiscoveryRequest request = builder.suite(Suite.class).build();
+		LauncherDiscoveryRequest request = builder.applySelectorsAndFiltersFromSuite(Suite.class).build();
 		assertTrue(request.getSelectorsByType(DirectorySelector.class).isEmpty());
 	}
 
@@ -461,7 +462,7 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 		class Suite {
 		}
 
-		LauncherDiscoveryRequest request = builder.suite(Suite.class).build();
+		LauncherDiscoveryRequest request = builder.applySelectorsAndFiltersFromSuite(Suite.class).build();
 		List<FileSelector> selectors = request.getSelectorsByType(FileSelector.class);
 		assertEquals(Paths.get("path/to/root"), exactlyOne(selectors).getPath());
 	}
@@ -473,7 +474,7 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 		class Suite {
 		}
 
-		LauncherDiscoveryRequest request = builder.suite(Suite.class).build();
+		LauncherDiscoveryRequest request = builder.applySelectorsAndFiltersFromSuite(Suite.class).build();
 		List<FileSelector> selectors = request.getSelectorsByType(FileSelector.class);
 		assertEquals(Optional.of(FilePosition.from(42)), selectors.get(0).getPosition());
 		assertEquals(Optional.of(FilePosition.from(14, 15)), selectors.get(1).getPosition());
@@ -487,7 +488,7 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 		class Suite {
 		}
 
-		LauncherDiscoveryRequest request = builder.suite(Suite.class).build();
+		LauncherDiscoveryRequest request = builder.applySelectorsAndFiltersFromSuite(Suite.class).build();
 		List<FileSelector> selectors = request.getSelectorsByType(FileSelector.class);
 		assertEquals(Optional.empty(), selectors.get(0).getPosition());
 		assertEquals(Optional.empty(), selectors.get(1).getPosition());
@@ -500,7 +501,7 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 		class Suite {
 		}
 
-		LauncherDiscoveryRequest request = builder.suite(Suite.class).build();
+		LauncherDiscoveryRequest request = builder.applySelectorsAndFiltersFromSuite(Suite.class).build();
 		List<ModuleSelector> selectors = request.getSelectorsByType(ModuleSelector.class);
 		assertEquals("com.example.testcases", exactlyOne(selectors).getModuleName());
 	}
@@ -511,7 +512,7 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 		class Suite {
 		}
 
-		LauncherDiscoveryRequest request = builder.suite(Suite.class).build();
+		LauncherDiscoveryRequest request = builder.applySelectorsAndFiltersFromSuite(Suite.class).build();
 		List<UriSelector> selectors = request.getSelectorsByType(UriSelector.class);
 		assertEquals(URI.create("path/to/root"), exactlyOne(selectors).getUri());
 	}
@@ -522,7 +523,7 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 		class Suite {
 		}
 
-		LauncherDiscoveryRequest request = builder.suite(Suite.class).build();
+		LauncherDiscoveryRequest request = builder.applySelectorsAndFiltersFromSuite(Suite.class).build();
 		assertTrue(request.getSelectorsByType(UriSelector.class).isEmpty());
 	}
 
@@ -532,7 +533,7 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 		class Suite {
 		}
 
-		LauncherDiscoveryRequest request = builder.suite(Suite.class).build();
+		LauncherDiscoveryRequest request = builder.applySelectorsAndFiltersFromSuite(Suite.class).build();
 		List<PackageSelector> selectors = request.getSelectorsByType(PackageSelector.class);
 		assertEquals("com.example.testcases", exactlyOne(selectors).getPackageName());
 	}
@@ -548,7 +549,7 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 		class Suite {
 		}
 
-		LauncherDiscoveryRequest request = builder.suite(Suite.class).build();
+		LauncherDiscoveryRequest request = builder.applySelectorsAndFiltersFromSuite(Suite.class).build();
 		List<PackageSelector> pSelectors = request.getSelectorsByType(PackageSelector.class);
 		assertEquals("com.example.testcases", exactlyOne(pSelectors).getPackageName());
 	}
@@ -560,7 +561,7 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 		}
 		// @formatter:off
 		var configuration = new ParentConfigurationParameters("parent", "parent parameters were used");
-		var request = builder.suite(Suite.class)
+		var request = builder.applyConfigurationParametersFromSuite(Suite.class)
 				.parentConfigurationParameters(configuration)
 				.build();
 		// @formatter:on
@@ -576,7 +577,7 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 		}
 		// @formatter:off
 		var configuration = new ParentConfigurationParameters("parent", "parent parameters were used");
-		var request = builder.suite(Suite.class)
+		var request = builder.applyConfigurationParametersFromSuite(Suite.class)
 				.parentConfigurationParameters(configuration)
 				.build();
 		// @formatter:on
